@@ -22,7 +22,7 @@
 #include <gtk/gtk.h>
 
 #define	prog_name	"cbrPager"
-#define prog_version	"0.9.24"
+#define prog_version	"0.9.25"
 
 #define FOLLOW_TIMER	150
 
@@ -37,7 +37,6 @@ enum {	ACC_FUNCTION,
 	ACC_COLS
 };
 
-
 typedef struct {
   // Preferences that are saved
   char	lastbook[200],
@@ -57,7 +56,8 @@ typedef struct {
         zone_size,		/* Size of scroll zone, in pels */
         buffer_size,            /* Image buffer size, in KB */
         scrollbars_fullscreen,  /* Whether to show scrollbars when fullscreen */
-        rotate_ccw;		/* Whether rotation is counter-clockwise (default clockwise) */
+        rotate_ccw,		/* Whether rotation is counter-clockwise (default clockwise) */
+        sort_order;            	/* Sort order: ascii, case insensitive or natural */
 	
   // Preferences that are not remembered
   char  explicit_file;
