@@ -47,6 +47,12 @@ typedef struct {
     char *sign;		/* Signature to compare to */
 } magic_sign;
 
+typedef enum { 
+    SORT_ASCII, 
+    SORT_CASE_INSENSITIVE, 
+    SORT_NATURAL
+} SortStrategy;
+
 struct _GArchiveReaderClass
 {
     GTypeInterface parent;
@@ -58,6 +64,8 @@ struct _GArchiveReaderClass
 					  gdouble* w,
 					  gdouble* h);
     gchar*         (*get_last_error)     (GArchiveReader* reader);
+    void           (*set_sort_strategy)  (GArchiveReader* reader,
+					  SortStrategy strategy);
 };
 
 GType       g_archive_reader_get_type (void) G_GNUC_CONST;
@@ -74,12 +82,17 @@ GdkPixbuf*  g_archive_reader_get_page     (GArchiveReader* reader,
 					   gdouble* w,
 					   gdouble* h);
 
+void g_archive_reader_set_sort_strategy(GArchiveReader* reader,
+					SortStrategy strategy);
+
 gchar* g_archive_reader_get_last_error(GArchiveReader* reader);
 
 /* utility routine, placed here for lack of a better place */
 int         g_archive_reader_check_magic(const gchar* path,
 					 const magic_sign* magic);
 
+GCompareFunc g_archive_reader_translate_strategy(SortStrategy strategy);
+
 G_END_DECLS
 #endif
 				      
