@@ -176,6 +176,8 @@ initial_setup(void)
 						 sz_list_command,
 						 sz_decompress_command);
 
+  set_sort_strategy();
+
   accel_table = g_hash_table_new(g_str_hash,
 				 g_str_equal);
   g_hash_table_insert(accel_table,
@@ -199,6 +201,9 @@ initial_setup(void)
   g_hash_table_insert(accel_table,
 		      "page_up",
 		      page_up);
+  g_hash_table_insert(accel_table,
+		      "goto_page",
+		      goto_page);
 }
 
 void
@@ -220,7 +225,17 @@ clean_up(void)
   image_buffer = NULL;
 }
 
-
+void
+set_sort_strategy(void)
+{
+  int i;
+  for(i = 0; i < NUM_READERS; ++i)
+    g_archive_reader_set_sort_strategy(readers[i],
+				       (SortStrategy)pref.sort_order);
+  /* re-request the current page */
+  if(pagelist && pagelist->len > 0)
+    show_page(page_nr);
+}
 
 void
 start_show(void)
@@ -297,7 +312,7 @@ draw_indicators(GtkWidget* canvas, int which)
   case 0:
     if(page_nr != 0)
       draw_indicators(canvas, -1);
-    if(page_nr + pref.nrpages < pagelist->len)
+    if(pagelist && page_nr + pref.nrpages < pagelist->len)
       draw_indicators(canvas, 1);
     /* set up a timer to remove the arrows after a time */
     if(timeout_id != 0) {
@@ -503,7 +518,7 @@ show_page(int nr)
   double w, h, w1 = 0, h1 = 0;
   int nr_pages;
 
-  nr_pages = pagelist->len;
+  nr_pages = pagelist ? pagelist->len : 0;
 
   if(reader == NULL || !nr_pages) {
     printf(_("No pages loaded\n"));
@@ -623,7 +638,7 @@ fit_width(int w)
 void
 next_page(int adv, gboolean show_indicator)
 {
-  int by = adv, nr_pages = pagelist->len;
+  int by = adv, nr_pages = pagelist ? pagelist->len : 0;
 
   if (by == 0) by = pref.nrpages;
   if (page_nr == (nr_pages - by)) {
@@ -680,6 +695,8 @@ goto_begin(void)
 void
 goto_end(void)
 {
+  if(!pagelist)
+    return;
   page_nr = pagelist->len - pref.nrpages;
   show_page(page_nr);
 }
@@ -921,13 +938,15 @@ main_canvas_keyevent(GdkEventKey *event, gboolean is_pressed)
     return;
   } else {
     /* workaround Maemo bug--dpad does not return key events properly,
-     * so use the key up event instead of key down 
+     * so use the key up event instead of key down.  Same problem with
+     * escape key (this would sometimes crash the whole program!)
      */
     switch(event->keyval) {
     case HILDON_HARDKEY_LEFT:
     case HILDON_HARDKEY_RIGHT:
     case HILDON_HARDKEY_UP:
     case HILDON_HARDKEY_DOWN:
+    case HILDON_HARDKEY_ESC:
       if(is_pressed)
 	return;
       break;
@@ -997,7 +1016,7 @@ main_canvas_buttonpressed(GdkEventButton *event)
 
   if (event->type != GDK_BUTTON_PRESS) return;
 
-  nr_pages = pagelist->len;
+  nr_pages = pagelist ? pagelist->len : 0;
 
   switch (event->button) {
   case 1:				// Left button
@@ -1133,10 +1152,10 @@ about_box(GtkWidget* main_window)
 }
 
 void
-goto_page(GtkWidget* main_window)
+goto_page()
 {
-  int nr_pages = pagelist->len;
-  int result = invoke_goto_page_dialog(main_window, 
+  int nr_pages = pagelist ? pagelist->len : 0;
+  int result = invoke_goto_page_dialog(MainWindow, 
 				       page_nr, 
 				       nr_pages - pref.nrpages);
   if(result >= 0) {
